@@ -20,7 +20,7 @@ use experimental qw( lexical_subs postderef signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.2.0';
 
 
 has header => (
@@ -111,6 +111,8 @@ sub weave_section( $self, $document, $input ) {
 
     my $release = $changelog->find_release($version) or return;
 
+    my @entries = _release_to_pod($release) or return;
+
     my $text = "Changes for version " . $version;
     if ( my $date = $release->date ) {
         $text .= sprintf( ' (%s)', substr( $date, 0, 10 ) );
@@ -123,7 +125,7 @@ sub weave_section( $self, $document, $input ) {
             content  => $self->header,
             children => [
                 Pod::Elemental::Element::Pod5::Ordinary->new( { content => $text } ),
-                _release_to_pod($release),
+                @entries,
                 Pod::Elemental::Element::Pod5::Ordinary->new(
                     { content => sprintf( 'See the F<%s> file for more details.', $self->changelog ) }
                 )
@@ -164,7 +166,7 @@ Pod::Weaver::Section::RecentChanges - generate POD with the recent changes
 
 =head1 VERSION
 
-version v0.1.2
+version v0.2.0
 
 =head1 SYNOPSIS
 
